@@ -27,48 +27,39 @@
 #' only the first column is retained. These columns are renamed with a prefix
 #' of "o_" and "d_".
 #' @param FUN Function to use on aggregation. Default is sum.
-#' @param prop_by_area Boolean value indicating if the values should be
-#' proportionally adjusted based on area. Default is TRUE unless FUN = mean.
-#' @param digits The number of digits to use when proportionally adjusting
-#' values based on area. Default is the value of getOption("digits").
-#'
+#' @inheritParams sp_aggregate
 #' @return data.frame containing the aggregated od flows.
 #'
 #' @export
 #' @examples
-#' data(flow)
-#' data(zones)
-#' zones@data$region <- NULL
 #' zones$quadrant = c(1, 2, 1, 4, 5, 6, 7, 1)
 #' aggzones <- rgeos::gUnaryUnion(zones, id = zones@data$quadrant)
-#' aggzones <- SpatialPolygonsDataFrame(aggzones, data.frame(region = c(1:6)), match.ID = FALSE)
+#' aggzones <- sp::SpatialPolygonsDataFrame(aggzones, data.frame(region = c(1:6)), match.ID = FALSE)
 #' sp::proj4string(aggzones) = sp::proj4string(zones)
-#' od_ag = od_aggregate(flow, zones, aggzones)
-#' od_ag = na.omit(od_ag)
-#' od_sp = od2line(od_ag, aggzones)
-#' plot(aggzones)
-#' plot(zones, lty = 3, add = TRUE)
-#' plot(flowlines, lwd = flowlines$All / 10, col = "grey", add = TRUE)
-#' plot(od_sp, lwd = od_sp$All / 30, col = "red", add = TRUE)
-#' # Sf methods
 #' aggzones_sf <- sf::st_as_sf(aggzones)
 #' aggzones_sf <- sf::st_set_crs(aggzones_sf, sf::st_crs(zones_sf))
 #' od_agg <- od_aggregate(flow, zones_sf, aggzones_sf)
+#' colSums(od_agg[3:9]) == colSums(flow[3:9])
 #' od_sf_agg <- od2line(od_agg, aggzones_sf)
-#' plot(od_sf_agg$geometry, lwd = od_sf_agg$All / 50, col = "blue", add = TRUE)
+#' plot(flowlines, lwd = flowlines$Bicycle)
+#' plot(od_sf_agg$geometry, lwd = od_sf_agg$Bicycle, add = TRUE, col = "red")
 od_aggregate <- function(flow, zones, aggzones,
-                         aggzone_points = NULL, cols = FALSE, aggcols = FALSE,
+                         aggzone_points = NULL,
+                         cols = FALSE,
+                         aggcols = FALSE,
                          FUN = sum,
                          prop_by_area = ifelse(identical(FUN, mean) == FALSE, TRUE, FALSE),
-                         digits = getOption("digits")){
+                         digits = getOption("digits")) {
   UseMethod("od_aggregate", zones)
 }
 #' @export
 od_aggregate.sf <- function(flow, zones, aggzones,
-                         aggzone_points = NULL, cols = FALSE, aggcols = FALSE,
-                         FUN = sum,
-                         prop_by_area = ifelse(identical(FUN, mean) == FALSE, TRUE, FALSE),
-                         digits = getOption("digits")){
+                            aggzone_points = NULL,
+                            cols = FALSE,
+                            aggcols = FALSE,
+                            FUN = sum,
+                            prop_by_area = ifelse(identical(FUN, mean) == FALSE, TRUE, FALSE),
+                            digits = getOption("digits")) {
 
   flow_first_col <- colnames(flow)[1]
   flow_second_col <- colnames(flow)[2]
@@ -88,26 +79,24 @@ od_aggregate.sf <- function(flow, zones, aggzones,
     aggzone_points <- sf::st_centroid(aggzones)
   }
 
-  aggflow_lines <- points2line(aggzone_points)
-
   zones_agg <- zone_points %>%
     sf::st_join(y = aggzones[aggcols]) %>%
     sf::st_set_geometry(NULL)
 
   names(zones_agg)[1] <- flow_first_col
+  zones_agg$new_orig = zones_agg[, aggcols[1]]
+  zones_agg$new_dest = zones_agg[, aggcols[1]]
 
-  flow$flow_new_orig <- flow[1] %>%
-    dplyr::inner_join(y = zones_agg[c(flow_first_col, aggcols)]) %>%
-    dplyr::pull(aggcols)
+  flow_new_orig <- flow %>%
+    dplyr::inner_join(y = zones_agg[c(flow_first_col, "new_orig")])
 
   names(zones_agg)[1] <- flow_second_col
 
-  flow$flow_new_dest <- flow[2] %>%
-    dplyr::inner_join(y = zones_agg[c(flow_second_col, aggcols)]) %>%
-    dplyr::pull(aggcols)
+  flow_new_dest <- flow_new_orig %>%
+    dplyr::inner_join(y = zones_agg[c(flow_second_col, "new_dest")])
 
-  flow_ag <- flow %>%
-    dplyr::group_by(.data$flow_new_orig, .data$flow_new_dest) %>%
+  flow_ag <- flow_new_dest %>%
+    dplyr::group_by(!!rlang::sym("new_orig"), !!rlang::sym("new_dest")) %>%
     dplyr::summarise_at(.vars = cols, .funs = sum) %>%
     dplyr::ungroup()
 
@@ -118,10 +107,12 @@ od_aggregate.sf <- function(flow, zones, aggzones,
 }
 #' @export
 od_aggregate.Spatial <- function(flow, zones, aggzones,
-                         aggzone_points = NULL, cols = FALSE, aggcols = FALSE,
-                         FUN = sum,
-                         prop_by_area = ifelse(identical(FUN, mean) == FALSE, TRUE, FALSE),
-                         digits = getOption("digits")){
+                                 aggzone_points = NULL,
+                                 cols = FALSE,
+                                 aggcols = FALSE,
+                                 FUN = sum,
+                                 prop_by_area = ifelse(identical(FUN, mean) == FALSE, TRUE, FALSE),
+                                 digits = getOption("digits")) {
   zonesfirstcol <- colnames(zones@data)[1]
   aggzonesfirstcol <- colnames(aggzones@data)[1]
 
@@ -223,17 +214,18 @@ od_aggregate.Spatial <- function(flow, zones, aggzones,
 #'
 #' @export
 #' @examples
-#' data(flow)
-#' data(zones)
+#' \dontrun{
 #' zones@data$region <- 1
 #' zones@data[c(2, 5), c('region')] <- 2
-#' aggzones <- SpatialPolygonsDataFrame(rgeos::gUnaryUnion(
+#' aggzones <- sp::SpatialPolygonsDataFrame(rgeos::gUnaryUnion(
 #'  zones,
 #'  id = zones@data$region), data.frame(region=c(1, 2))
 #' )
 #' zones@data$region <- NULL
 #' zones@data$exdata <- 5
+#' library(sp)
 #' sp_aggregate(zones, aggzones)
+#' }
 sp_aggregate <- function(zones, aggzones, cols = FALSE,
                          FUN = sum,
                          prop_by_area = ifelse(identical(FUN, mean) == FALSE, TRUE, FALSE),
@@ -306,4 +298,4 @@ sp_aggregate <- function(zones, aggzones, cols = FALSE,
 
   return(aggzones)
 
-}
\ No newline at end of file
+}
